@@ -12,8 +12,18 @@ parser.add_option("-d", "--default-template", dest="default_template", help="set
 
 
 def create_template():
-    templates_dir = os.path.join(kickstarter.__path__[0], 'templates')
-    shutil.copytree(options.new_template, '%s/%s' % (templates_dir, os.path.dirname(options.new_template)))
+    if os.path.exists('./%s' % options.new_template):
+        override = raw_input('%s already exists. Override? [y/n]: ' % options.new_template)
+
+        if override == 'y':
+            templates_dir = os.path.join(kickstarter.__path__[0], 'templates')
+            shutil.rmtree('%s/%s' % (templates_dir, options.new_template))
+            shutil.copytree(options.new_template, '%s/%s' % (templates_dir, os.path.dirname(options.new_template)))
+        else:
+            print 'Aborting'
+    else:
+        templates_dir = os.path.join(kickstarter.__path__[0], 'templates')
+        shutil.copytree(options.new_template, '%s/%s' % (templates_dir, os.path.dirname(options.new_template)))
 
 
 def set_default_template():
@@ -39,15 +49,16 @@ def create_project():
         return config[key]
 
     def config_prompt():
-        c = open('%s/%s' % (template_dir, 'config.yaml'), 'r')
-        parsed_conf = re.sub('{{\s*(\w+)\s*}}', args[0], c.read())
-        c.close()
+        if os.path.exists('%s/%s' % (template_dir, 'config.yaml')):
+            c = open('%s/%s' % (template_dir, 'config.yaml'), 'r')
+            parsed_conf = re.sub('{{\s*(\w+)\s*}}', args[0], c.read())
+            c.close()
 
-        conf = yaml.load(parsed_conf)
-        for option in conf:
-            default = conf[option]
-            value = str(raw_input('%s (leave blank for %s): ' % (option, default)))
-            config[option.lower()] = value if value != '' else default
+            conf = yaml.load(parsed_conf)
+            for option in conf:
+                default = conf[option]
+                value = str(raw_input('%s (leave blank for %s): ' % (option, default)))
+                config[option.lower()] = value if value != '' else default
 
     def copy_template():
         config_prompt()
